@@ -14,6 +14,16 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+ * 
+ * Additional permission under GNU GPL version 3 section 7
+ *
+ * If you modify this program, or any covered work, by linking or combining
+ * it with the OpenSSL library (or a modified version of that library),
+ * containing parts covered by the terms of the OpenSSL license, the licensors
+ * of this program grant you additional permission to convey the resulting work.
+ * Corresponding source for a non-source form of such a combination shall include
+ * the source code for the parts of the OpenSSL library used as well as that of
+ * the covered work.
  */
 
 #include <iostream>
@@ -48,6 +58,11 @@
 
 
 int main(int argc, char** argv){
+	if (argc == 2 && (std::string(argv[1]) == "-v" || std::string(argv[1]) == "--version")) {
+		std::cout << "Grub Customizer, version " << GC_VERSION << std::endl;
+		return 0;
+	}
+
 	if (getuid() != 0 && (argc == 1 || argv[1] != std::string("no-fork"))) {
 		return system((std::string("xhost +SI:localuser:root; pkexec ") + argv[0] + (argc == 2 ? std::string(" ") + argv[1] : "") + " no-fork; xhost -SI:localuser:root").c_str());
 	}
